@@ -2,7 +2,7 @@
 
 import typer
 
-from . import format_data, populate, publisher, query, scaffold, test, update, validator
+from . import format_data, populate, publisher, query, scaffold, test, unpublisher, update, validator
 from . import list as list_cmd
 
 app = typer.Typer()
@@ -13,6 +13,7 @@ app.add_typer(scaffold.app, name="init")
 app.add_typer(list_cmd.app, name="list")
 app.add_typer(query.app, name="query")
 app.add_typer(publisher.app, name="publish")
+app.add_typer(unpublisher.app, name="unpublish")
 app.add_typer(update.app, name="update")
 app.add_typer(test.app, name="test")
 
