@@ -81,20 +81,24 @@ class SellerTypeEnum(StrEnum):
 
 
 class ListingStatusEnum(StrEnum):
-    # Not yet determined
-    unknown = "unknown"
-    # step 1: upstream is ready to be used
-    upstream_ready = "upstream_ready"
-    # step 2: downstream is ready, with proper routing, logging, and billing
-    downstream_ready = "downstream_ready"
-    # step 3: service is operationally ready (with proper documentation and initial
-    # performance metrics, and pricing strategy)
+    """
+    Listing status values that sellers can set locally.
+
+    Seller-accessible statuses:
+    - draft: Listing is being worked on, skipped during publish (won't be sent to backend)
+    - ready: Listing is complete and ready for admin review/testing
+    - deprecated: Seller marks service as retired/replaced
+
+    Note: Admin-managed workflow statuses (upstream_ready, downstream_ready, in_service)
+    are set by the backend admin after testing and validation. These are not included in this
+    enum since sellers cannot set them through the CLI tool.
+    """
+
+    # Still being worked on - skip during publish
+    draft = "draft"
+    # Ready for admin review and testing
     ready = "ready"
-    # step 4: service is in service
-    in_service = "in_service"
-    # step 5.1: service is deprecated from upstream
-    upstream_deprecated = "upstream_deprecated"
-    # step 5.2: service is no longer offered to users (due to business reasons)
+    # No longer offered
     deprecated = "deprecated"
 
 
@@ -214,7 +218,7 @@ class ProviderStatusEnum(StrEnum):
     active = "active"
     pending = "pending"
     disabled = "disabled"
-    incomplete = "incomplete"  # Provider information is incomplete
+    draft = "draft"  # Provider information is incomplete, skip during publish
 
 
 class SellerStatusEnum(StrEnum):
@@ -223,7 +227,7 @@ class SellerStatusEnum(StrEnum):
     active = "active"
     pending = "pending"
     disabled = "disabled"
-    incomplete = "incomplete"  # Seller information is incomplete
+    draft = "draft"  # Seller information is incomplete, skip during publish
 
 
 class Document(BaseModel):
@@ -324,7 +328,7 @@ class AccessInterface(BaseModel):
 
     access_method: AccessMethodEnum = Field(default=AccessMethodEnum.http, description="Type of access method")
 
-    api_endpoint: str = Field(max_length=500, description="API endpoint URL")
+    base_url: str = Field(max_length=500, description="Base URL for api access")
 
     api_key: str | None = Field(default=None, max_length=2000, description="API key if required")
 
@@ -336,6 +340,11 @@ class AccessInterface(BaseModel):
         default=None, description="Request transformation configuration"
     )
 
+    routing_key: dict[str, Any] | None = Field(
+        default=None,
+        description="Request routing key for matching (e.g., {'model': 'gpt-4'})",
+    )
+
     documents: list[Document] | None = Field(
         default=None, description="List of documents associated with the interface"
     )
