@@ -4,7 +4,6 @@ import asyncio
 import base64
 import json
 import os
-import tomllib as toml
 from pathlib import Path
 from typing import Any
 
@@ -16,8 +15,8 @@ from rich.table import Table
 import unitysvc_services
 
 from .api import UnitySvcAPI
-from .models.base import ProviderStatusEnum, SellerStatusEnum
-from .utils import convert_convenience_fields_to_documents, find_files_by_schema, render_template_file
+from .models.base import ListingStatusEnum, ProviderStatusEnum, SellerStatusEnum
+from .utils import convert_convenience_fields_to_documents, find_files_by_schema, load_data_file, render_template_file
 from .validator import DataValidator
 
 
@@ -35,17 +34,6 @@ class ServiceDataPublisher(UnitySvcAPI):
         # Semaphore to limit concurrent requests and prevent connection pool exhaustion
         self.max_concurrent_requests = 15
 
-    def load_data_file(self, file_path: Path) -> dict[str, Any]:
-        """Load data from JSON or TOML file."""
-        if file_path.suffix == ".toml":
-            with open(file_path, "rb") as f:
-                return toml.load(f)
-        elif file_path.suffix == ".json":
-            with open(file_path, encoding="utf-8") as f:
-                return json.load(f)
-        else:
-            raise ValueError(f"Unsupported file format: {file_path.suffix}")
-
     def load_file_content(self, file_path: Path, base_path: Path) -> str:
         """Load content from a file (text or binary)."""
         full_path = base_path / file_path if not file_path.is_absolute() else file_path
@@ -71,6 +59,7 @@ class ServiceDataPublisher(UnitySvcAPI):
         provider: dict[str, Any] | None = None,
         seller: dict[str, Any] | None = None,
         listing_filename: str | None = None,
+        interface: dict[str, Any] | None = None,
     ) -> dict[str, Any]:
         """Recursively resolve file references and include content in data.
 
@@ -85,12 +74,19 @@ class ServiceDataPublisher(UnitySvcAPI):
             provider: Provider data for template rendering (optional)
             seller: Seller data for template rendering (optional)
             listing_filename: Listing filename for constructing output filenames (optional)
+            interface: AccessInterface data for template rendering (optional, for interface documents)
 
         Returns:
             Data with file references resolved and content loaded
         """
         result: dict[str, Any] = {}
 
+        # Check if this dict looks like an AccessInterface (has base_url or interface_type)
+        # If so, use it as the interface context for nested documents
+        current_interface = interface
+        if "base_url" in data or "interface_type" in data:
+            current_interface = data
+
         for key, value in data.items():
             if isinstance(value, dict):
                 # Recursively process nested dictionaries
@@ -102,6 +98,7 @@ class ServiceDataPublisher(UnitySvcAPI):
                     provider=provider,
                     seller=seller,
                     listing_filename=listing_filename,
+                    interface=current_interface,
                 )
             elif isinstance(value, list):
                 # Process lists
@@ -115,6 +112,7 @@ class ServiceDataPublisher(UnitySvcAPI):
                             provider=provider,
                             seller=seller,
                             listing_filename=listing_filename,
+                            interface=current_interface,
                         )
                         if isinstance(item, dict)
                         else item
@@ -136,6 +134,7 @@ class ServiceDataPublisher(UnitySvcAPI):
                         offering=offering,
                         provider=provider,
                         seller=seller,
+                        interface=current_interface,
                     )
                     result["file_content"] = content
 
@@ -344,7 +343,7 @@ class ServiceDataPublisher(UnitySvcAPI):
     ) -> dict[str, Any]:
         """Async version of post_service_listing for concurrent publishing with retry logic."""
         # Load the listing data file
-        data = self.load_data_file(listing_file)
+        data, _ = load_data_file(listing_file)
 
         # If name is not provided, use filename (without extension)
         if "name" not in data or not data.get("name"):
@@ -433,9 +432,9 @@ class ServiceDataPublisher(UnitySvcAPI):
         # Should only be one seller file in the data directory
         _seller_file, _format, seller_data = seller_files[0]
 
-        # Check seller status - skip if incomplete
+        # Check seller status - skip if draft
         seller_status = seller_data.get("status", SellerStatusEnum.active)
-        if seller_status == SellerStatusEnum.incomplete:
+        if seller_status == SellerStatusEnum.draft:
             return {
                 "skipped": True,
                 "reason": f"Seller status is '{seller_status}' - not publishing listing to backend",
@@ -452,6 +451,15 @@ class ServiceDataPublisher(UnitySvcAPI):
         if "listing_status" in data:
             data["status"] = data.pop("listing_status")
 
+        # Check listing status - skip if draft
+        listing_status = data.get("status", ListingStatusEnum.ready)
+        if listing_status == ListingStatusEnum.draft:
+            return {
+                "skipped": True,
+                "reason": f"Listing status is '{listing_status}' - not publishing to backend (still in draft)",
+                "name": data.get("name", "unknown"),
+            }
+
         # NOW resolve file references with all context (listing, offering, provider, seller)
         base_path = listing_file.parent
         data_with_content = self.resolve_file_references(
@@ -492,7 +500,7 @@ class ServiceDataPublisher(UnitySvcAPI):
     ) -> dict[str, Any]:
         """Async version of post_service_offering for concurrent publishing with retry logic."""
         # Load the data file
-        data = self.load_data_file(data_file)
+        data, _ = load_data_file(data_file)
 
         # Convert convenience fields first
         base_path = data_file.parent
@@ -522,7 +530,7 @@ class ServiceDataPublisher(UnitySvcAPI):
             # Should only be one provider file in the directory
             _provider_file, _format, provider_data = provider_files[0]
             provider_status = provider_data.get("status", ProviderStatusEnum.active)
-            if provider_status == ProviderStatusEnum.incomplete:
+            if provider_status == ProviderStatusEnum.draft:
                 return {
                     "skipped": True,
                     "reason": f"Provider status is '{provider_status}' - not publishing offering to backend",
@@ -561,11 +569,11 @@ class ServiceDataPublisher(UnitySvcAPI):
     async def post_provider_async(self, data_file: Path, max_retries: int = 3, dryrun: bool = False) -> dict[str, Any]:
         """Async version of post_provider for concurrent publishing with retry logic."""
         # Load the data file
-        data = self.load_data_file(data_file)
+        data, _ = load_data_file(data_file)
 
-        # Check provider status - skip if incomplete
+        # Check provider status - skip if draft
         provider_status = data.get("status", ProviderStatusEnum.active)
-        if provider_status == ProviderStatusEnum.incomplete:
+        if provider_status == ProviderStatusEnum.draft:
             # Return success without publishing - provider is incomplete
             return {
                 "skipped": True,
@@ -602,11 +610,11 @@ class ServiceDataPublisher(UnitySvcAPI):
     async def post_seller_async(self, data_file: Path, max_retries: int = 3, dryrun: bool = False) -> dict[str, Any]:
         """Async version of post_seller for concurrent publishing with retry logic."""
         # Load the data file
-        data = self.load_data_file(data_file)
+        data, _ = load_data_file(data_file)
 
-        # Check seller status - skip if incomplete
+        # Check seller status - skip if draft
         seller_status = data.get("status", SellerStatusEnum.active)
-        if seller_status == SellerStatusEnum.incomplete:
+        if seller_status == SellerStatusEnum.draft:
             # Return success without publishing - seller is incomplete
             return {
                 "skipped": True,
@@ -681,7 +689,7 @@ class ServiceDataPublisher(UnitySvcAPI):
         async with semaphore:  # Limit concurrent requests
             try:
                 # Load offering data to get the name
-                data = self.load_data_file(offering_file)
+                data, _ = load_data_file(offering_file)
                 offering_name = data.get("name", offering_file.stem)
 
                 # Publish the offering
@@ -702,7 +710,7 @@ class ServiceDataPublisher(UnitySvcAPI):
 
                 return (offering_file, result)
             except Exception as e:
-                data = self.load_data_file(offering_file)
+                data, _ = load_data_file(offering_file)
                 offering_name = data.get("name", offering_file.stem)
                 console.print(f"  [red]✗[/red] Failed to publish offering: [cyan]{offering_name}[/cyan] - {str(e)}")
                 return (offering_file, e)
@@ -784,7 +792,7 @@ class ServiceDataPublisher(UnitySvcAPI):
         async with semaphore:  # Limit concurrent requests
             try:
                 # Load listing data to get the name
-                data = self.load_data_file(listing_file)
+                data, _ = load_data_file(listing_file)
                 listing_name = data.get("name", listing_file.stem)
 
                 # Publish the listing
@@ -806,7 +814,7 @@ class ServiceDataPublisher(UnitySvcAPI):
 
                 return (listing_file, result)
             except Exception as e:
-                data = self.load_data_file(listing_file)
+                data, _ = load_data_file(listing_file)
                 listing_name = data.get("name", listing_file.stem)
                 console.print(f"  [red]✗[/red] Failed to publish listing: [cyan]{listing_file}[/cyan] - {str(e)}")
                 return (listing_file, e)
@@ -884,7 +892,7 @@ class ServiceDataPublisher(UnitySvcAPI):
         async with semaphore:  # Limit concurrent requests
             try:
                 # Load provider data to get the name
-                data = self.load_data_file(provider_file)
+                data, _ = load_data_file(provider_file)
                 provider_name = data.get("name", provider_file.stem)
 
                 # Publish the provider
@@ -903,7 +911,7 @@ class ServiceDataPublisher(UnitySvcAPI):
 
                 return (provider_file, result)
             except Exception as e:
-                data = self.load_data_file(provider_file)
+                data, _ = load_data_file(provider_file)
                 provider_name = data.get("name", provider_file.stem)
                 console.print(f"  [red]✗[/red] Failed to publish provider: [cyan]{provider_name}[/cyan] - {str(e)}")
                 return (provider_file, e)
@@ -968,7 +976,7 @@ class ServiceDataPublisher(UnitySvcAPI):
         async with semaphore:  # Limit concurrent requests
             try:
                 # Load seller data to get the name
-                data = self.load_data_file(seller_file)
+                data, _ = load_data_file(seller_file)
                 seller_name = data.get("name", seller_file.stem)
 
                 # Publish the seller
@@ -987,7 +995,7 @@ class ServiceDataPublisher(UnitySvcAPI):
 
                 return (seller_file, result)
             except Exception as e:
-                data = self.load_data_file(seller_file)
+                data, _ = load_data_file(seller_file)
                 seller_name = data.get("name", seller_file.stem)
                 console.print(f"  [red]✗[/red] Failed to publish seller: [cyan]{seller_name}[/cyan] - {str(e)}")
                 return (seller_file, e)
