@@ -2,7 +2,6 @@
 
 import fnmatch
 import os
-import shutil
 import subprocess
 import tempfile
 from pathlib import Path
@@ -12,8 +11,8 @@ import typer
 from rich.console import Console
 from rich.table import Table
 
-from .models.base import DocumentCategoryEnum
-from .utils import find_files_by_schema, render_template_file
+from .models.base import DocumentCategoryEnum, UpstreamStatusEnum
+from .utils import determine_interpreter, find_files_by_schema, render_template_file
 
 app = typer.Typer(help="Test code examples with upstream credentials")
 console = Console()
@@ -87,6 +86,7 @@ def extract_code_examples_from_listing(listing_data: dict[str, Any], listing_fil
                         "file_path": str(absolute_path),
                         "listing_data": listing_data,  # Full listing data for templates
                         "listing_file": listing_file,  # Path to listing file for loading related data
+                        "interface": interface,  # Interface data for templates (base_url, routing_key, etc.)
                         "expect": meta.get("expect"),  # Expected output substring for validation (from meta)
                         "requirements": meta.get("requirements"),  # Required packages (from meta)
                     }
@@ -159,7 +159,7 @@ def load_provider_credentials(listing_file: Path) -> dict[str, str] | None:
         listing_file: Path to the listing file (used to locate the service offering)
 
     Returns:
-        Dictionary with api_key and api_endpoint, or None if not found
+        Dictionary with api_key and base_url, or None if not found
     """
     try:
         # Load related data including the offering
@@ -172,12 +172,12 @@ def load_provider_credentials(listing_file: Path) -> dict[str, str] | None:
         # Extract credentials from upstream_access_interface
         upstream_access = offering.get("upstream_access_interface", {})
         api_key = upstream_access.get("api_key")
-        api_endpoint = upstream_access.get("api_endpoint")
+        base_url = upstream_access.get("base_url")
 
-        if api_key and api_endpoint:
+        if api_key and base_url:
             return {
                 "api_key": str(api_key),
-                "api_endpoint": str(api_endpoint),
+                "base_url": str(base_url),
             }
     except Exception as e:
         console.print(f"[yellow]Warning: Failed to load service credentials: {e}[/yellow]")
@@ -190,7 +190,7 @@ def execute_code_example(code_example: dict[str, Any], credentials: dict[str, st
 
     Args:
         code_example: Code example metadata with file_path and listing_data
-        credentials: Dictionary with api_key and api_endpoint
+        credentials: Dictionary with api_key and base_url
 
     Returns:
         Result dictionary with success, exit_code, stdout, stderr, rendered_content, file_suffix
@@ -231,6 +231,7 @@ def execute_code_example(code_example: dict[str, Any], credentials: dict[str, st
                 offering=related_data.get("offering", {}),
                 provider=related_data.get("provider", {}),
                 seller=related_data.get("seller", {}),
+                interface=code_example.get("interface", {}),
             )
         except Exception as e:
             result["error"] = f"Template rendering failed: {str(e)}"
@@ -245,66 +246,19 @@ def execute_code_example(code_example: dict[str, Any], credentials: dict[str, st
         result["listing_file"] = listing_file
         result["actual_filename"] = actual_filename
 
-        # Determine interpreter to use
-        lines = file_content.split("\n")
-        interpreter_cmd = None
+        # Determine interpreter to use (using shared utility function)
+        interpreter_cmd, error = determine_interpreter(file_content, file_suffix)
+        if error:
+            result["error"] = error
+            return result
 
-        # First, try to parse shebang
-        if lines and lines[0].startswith("#!"):
-            shebang = lines[0][2:].strip()
-            if "/env " in shebang:
-                # e.g., #!/usr/bin/env python3
-                interpreter_cmd = shebang.split("/env ", 1)[1].strip().split()[0]
-            else:
-                # e.g., #!/usr/bin/python3
-                interpreter_cmd = shebang.split("/")[-1].split()[0]
-
-        # If no shebang found, determine interpreter based on file extension
-        if not interpreter_cmd:
-            if file_suffix == ".py":
-                # Try python3 first, fallback to python
-                if shutil.which("python3"):
-                    interpreter_cmd = "python3"
-                elif shutil.which("python"):
-                    interpreter_cmd = "python"
-                else:
-                    result["error"] = "Neither 'python3' nor 'python' found. Please install Python to run this test."
-                    return result
-            elif file_suffix == ".js":
-                # JavaScript files need Node.js
-                if shutil.which("node"):
-                    interpreter_cmd = "node"
-                else:
-                    result["error"] = "'node' not found. Please install Node.js to run JavaScript tests."
-                    return result
-            elif file_suffix == ".sh":
-                # Shell scripts use bash
-                if shutil.which("bash"):
-                    interpreter_cmd = "bash"
-                else:
-                    result["error"] = "'bash' not found. Please install bash to run shell script tests."
-                    return result
-            else:
-                # Unknown file type - try python3/python as fallback
-                if shutil.which("python3"):
-                    interpreter_cmd = "python3"
-                elif shutil.which("python"):
-                    interpreter_cmd = "python"
-                else:
-                    result["error"] = f"Unknown file type '{file_suffix}' and no Python interpreter found."
-                    return result
-        else:
-            # Shebang was found - verify the interpreter exists
-            if not shutil.which(interpreter_cmd):
-                result["error"] = (
-                    f"Interpreter '{interpreter_cmd}' from shebang not found. Please install it to run this test."
-                )
-                return result
+        # At this point, interpreter_cmd is guaranteed to be a string (error check above)
+        assert interpreter_cmd is not None, "interpreter_cmd should not be None after error check"
 
         # Prepare environment variables
         env = os.environ.copy()
         env["API_KEY"] = credentials["api_key"]
-        env["API_ENDPOINT"] = credentials["api_endpoint"]
+        env["BASE_URL"] = credentials["base_url"]
 
         # Write script to temporary file with original extension
         with tempfile.NamedTemporaryFile(mode="w", suffix=file_suffix, delete=False) as temp_file:
@@ -358,6 +312,77 @@ def execute_code_example(code_example: dict[str, Any], credentials: dict[str, st
     return result
 
 
+def update_offering_override_status(listing_file: Path, status: UpstreamStatusEnum | None) -> None:
+    """Update or remove the status field in the offering override file.
+
+    Args:
+        listing_file: Path to the listing file (offering is in same directory)
+        status: Status to set (e.g., UpstreamStatusEnum.deprecated), or None to remove status field
+    """
+    import json
+
+    try:
+        # Find the offering file (service.json) in the same directory
+        offering_results = find_files_by_schema(listing_file.parent, "service_v1")
+        if not offering_results:
+            console.print(f"[yellow]⚠ No service offering file found in {listing_file.parent}[/yellow]")
+            return
+
+        # Get the base offering file path
+        offering_file_path, offering_format, _offering_data = offering_results[0]
+
+        # Construct override file path
+        override_path = offering_file_path.with_stem(f"{offering_file_path.stem}.override")
+
+        # Load existing override file if it exists
+        if override_path.exists():
+            try:
+                with open(override_path, encoding="utf-8") as f:
+                    if offering_format == "json":
+                        override_data = json.load(f)
+                    else:  # toml
+                        import tomli
+
+                        override_data = tomli.loads(f.read())
+            except Exception as e:
+                console.print(f"[yellow]⚠ Failed to read override file {override_path}: {e}[/yellow]")
+                override_data = {}
+        else:
+            override_data = {}
+
+        # Update or remove upstream_status field
+        if status is None:
+            # Remove upstream_status field if it exists and equals deprecated
+            if override_data.get("upstream_status") == UpstreamStatusEnum.deprecated:
+                del override_data["upstream_status"]
+                console.print("  [dim]→ Removed deprecated upstream_status from override file[/dim]")
+        else:
+            # Set upstream_status field
+            override_data["upstream_status"] = status.value
+            console.print(f"  [dim]→ Set upstream_status to {status.value} in override file[/dim]")
+
+        # Write override file (or delete if empty)
+        if override_data:
+            # Write the override file
+            with open(override_path, "w", encoding="utf-8") as f:
+                if offering_format == "json":
+                    json.dump(override_data, f, indent=2)
+                    f.write("\n")  # Add trailing newline
+                else:  # toml
+                    import tomli_w
+
+                    f.write(tomli_w.dumps(override_data))
+            console.print(f"  [dim]→ Updated override file: {override_path}[/dim]")
+        else:
+            # Delete override file if it's now empty
+            if override_path.exists():
+                override_path.unlink()
+                console.print(f"  [dim]→ Removed empty override file: {override_path}[/dim]")
+
+    except Exception as e:
+        console.print(f"[yellow]⚠ Failed to update override file: {e}[/yellow]")
+
+
 @app.command("list")
 def list_code_examples(
     data_dir: Path | None = typer.Argument(
@@ -551,6 +576,18 @@ def run(
         "-v",
         help="Show detailed output including stdout/stderr from scripts",
     ),
+    force: bool = typer.Option(
+        False,
+        "--force",
+        "-f",
+        help="Force rerun all tests, ignoring existing .out and .err files",
+    ),
+    fail_fast: bool = typer.Option(
+        False,
+        "--fail-fast",
+        "-x",
+        help="Stop testing on first failure",
+    ),
 ):
     """Test code examples with upstream API credentials.
 
@@ -558,8 +595,9 @@ def run(
     1. Scans for all listing files (schema: listing_v1)
     2. Extracts code example documents
     3. Loads provider credentials from provider.toml
-    4. Executes each code example with API_KEY and API_ENDPOINT set to upstream values
-    5. Displays test results
+    4. Skips tests that have existing .out and .err files (unless --force is used)
+    5. Executes each code example with API_KEY and BASE_URL set to upstream values
+    6. Displays test results
 
     Examples:
         # Test all code examples
@@ -582,6 +620,12 @@ def run(
 
         # Show detailed output
         unitysvc_services test run --verbose
+
+        # Force rerun all tests (ignore existing results)
+        unitysvc_services test run --force
+
+        # Stop on first failure
+        unitysvc_services test run --fail-fast
     """
     # Set data directory
     if data_dir is None:
@@ -675,14 +719,71 @@ def run(
 
     # Execute each code example
     results = []
+    skipped_count = 0
+
+    # Track test results per service offering (for status updates)
+    # Key: offering directory path, Value: {"passed": int, "failed": int, "listing_file": Path}
+    offering_test_results: dict[str, dict[str, Any]] = {}
 
     for example, prov_name, credentials in all_code_examples:
         service_name = example["service_name"]
         title = example["title"]
+        example_listing_file = example.get("listing_file")
+
+        # Determine actual filename (strip .j2 if it's a template)
+        file_path = example.get("file_path")
+        if file_path:
+            original_path = Path(file_path)
+            # If it's a .j2 template, the actual filename is without .j2
+            if original_path.suffix == ".j2":
+                actual_filename = original_path.stem
+            else:
+                actual_filename = original_path.name
+        else:
+            actual_filename = None
+
+        # Prepare output file paths if we have the necessary information
+        out_path = None
+        err_path = None
+        if example_listing_file and actual_filename:
+            listing_path = Path(example_listing_file)
+            listing_stem = listing_path.stem
+
+            # Create filename pattern: {service_name}_{listing_stem}_{actual_filename}.out/.err
+            # e.g., "llama-3-1-405b-instruct_svclisting_test.py.out"
+            base_filename = f"{service_name}_{listing_stem}_{actual_filename}"
+            out_filename = f"{base_filename}.out"
+            err_filename = f"{base_filename}.err"
+
+            # Output paths in the listing directory
+            out_path = listing_path.parent / out_filename
+            err_path = listing_path.parent / err_filename
+
+        # Check if test results already exist (skip if not forcing)
+        if not force and out_path and err_path and out_path.exists() and err_path.exists():
+            console.print(f"[bold]Testing:[/bold] {service_name} - {title}")
+            console.print("  [yellow]⊘ Skipped[/yellow] (results already exist)")
+            console.print()
+            skipped_count += 1
+            # Add a skipped result for the summary
+            results.append(
+                {
+                    "service_name": service_name,
+                    "provider": prov_name,
+                    "title": title,
+                    "result": {
+                        "success": True,
+                        "exit_code": None,
+                        "skipped": True,
+                    },
+                }
+            )
+            continue
 
         console.print(f"[bold]Testing:[/bold] {service_name} - {title}")
 
         result = execute_code_example(example, credentials)
+        result["skipped"] = False
 
         results.append(
             {
@@ -698,22 +799,8 @@ def run(
             if verbose and result["stdout"]:
                 console.print(f"  [dim]stdout:[/dim] {result['stdout'][:200]}")
 
-            # Save successful test output to .out and .err files
-            if result.get("listing_file") and result.get("actual_filename"):
-                listing_file = Path(result["listing_file"])
-                actual_filename = result["actual_filename"]
-                listing_stem = listing_file.stem
-
-                # Create filename pattern: {service_name}_{listing_stem}_{actual_filename}.out/.err
-                # e.g., "llama-3-1-405b-instruct_svclisting_test.py.out"
-                base_filename = f"{service_name}_{listing_stem}_{actual_filename}"
-                out_filename = f"{base_filename}.out"
-                err_filename = f"{base_filename}.err"
-
-                # Save to listing directory
-                out_path = listing_file.parent / out_filename
-                err_path = listing_file.parent / err_filename
-
+            # Save successful test output to .out and .err files (if paths were determined)
+            if out_path and err_path:
                 # Write stdout to .out file
                 try:
                     with open(out_path, "w", encoding="utf-8") as f:
@@ -730,6 +817,17 @@ def run(
                         console.print(f"  [dim]→ Error output saved to:[/dim] {err_path}")
                 except Exception as e:
                     console.print(f"  [yellow]⚠ Failed to save error output: {e}[/yellow]")
+
+            # Track test result for this offering (don't update status yet)
+            if example_listing_file and not test_file:
+                offering_dir = str(example_listing_file.parent)
+                if offering_dir not in offering_test_results:
+                    offering_test_results[offering_dir] = {
+                        "passed": 0,
+                        "failed": 0,
+                        "listing_file": example_listing_file,
+                    }
+                offering_test_results[offering_dir]["passed"] += 1
         else:
             console.print(f"  [red]✗ Failed[/red] - {result['error']}")
             if verbose:
@@ -739,14 +837,15 @@ def run(
                     console.print(f"  [dim]stderr:[/dim] {result['stderr'][:200]}")
 
             # Write failed test outputs and script to current directory
+            # Use actual_filename from result in case template rendering modified it
             if result.get("listing_file") and result.get("actual_filename"):
-                listing_file = Path(result["listing_file"])
-                actual_filename = result["actual_filename"]
-                listing_stem = listing_file.stem
+                result_listing_file = Path(result["listing_file"])
+                result_actual_filename = result["actual_filename"]
+                result_listing_stem = result_listing_file.stem
 
                 # Create filename: failed_{service_name}_{listing_stem}_{actual_filename}
                 # This will be the base name for .out, .err, and the script file
-                failed_filename = f"failed_{service_name}_{listing_stem}_{actual_filename}"
+                failed_filename = f"failed_{service_name}_{result_listing_stem}_{result_actual_filename}"
 
                 # Write stdout to .out file in current directory
                 out_filename = f"{failed_filename}.out"
@@ -768,32 +867,58 @@ def run(
 
                 # Write failed test script content to current directory (for debugging)
                 # rendered_content is always set if we got here (set during template rendering)
-                content_with_env = result["rendered_content"]
-
-                # Add environment variables as comments at the top
-                env_header = (
-                    "# Environment variables used for this test:\n"
-                    f"# API_KEY={credentials['api_key']}\n"
-                    f"# API_ENDPOINT={credentials['api_endpoint']}\n"
-                    "#\n"
-                    "# To reproduce this test, export these variables:\n"
-                    f"# export API_KEY='{credentials['api_key']}'\n"
-                    f"# export API_ENDPOINT='{credentials['api_endpoint']}'\n"
-                    "#\n\n"
-                )
-
-                content_with_env = env_header + content_with_env
-
                 try:
                     with open(failed_filename, "w", encoding="utf-8") as f:
-                        f.write(content_with_env)
+                        f.write(result["rendered_content"])
                     console.print(f"  [yellow]→ Test script saved to:[/yellow] {failed_filename}")
-                    console.print("  [dim]  (includes environment variables for reproduction)[/dim]")
                 except Exception as e:
                     console.print(f"  [yellow]⚠ Failed to save test script: {e}[/yellow]")
 
+                # Write environment variables to .env file
+                env_filename = f"{failed_filename}.env"
+                try:
+                    with open(env_filename, "w", encoding="utf-8") as f:
+                        f.write(f"API_KEY={credentials['api_key']}\n")
+                        f.write(f"BASE_URL={credentials['base_url']}\n")
+                    console.print(f"  [yellow]→ Environment variables saved to:[/yellow] {env_filename}")
+                    console.print(f"  [dim]  (source this file to reproduce: source {env_filename})[/dim]")
+                except Exception as e:
+                    console.print(f"  [yellow]⚠ Failed to save environment file: {e}[/yellow]")
+
+            # Track test result for this offering (don't update status yet)
+            if example_listing_file and not test_file:
+                offering_dir = str(example_listing_file.parent)
+                if offering_dir not in offering_test_results:
+                    offering_test_results[offering_dir] = {
+                        "passed": 0,
+                        "failed": 0,
+                        "listing_file": example_listing_file,
+                    }
+                offering_test_results[offering_dir]["failed"] += 1
+
+            # Stop testing if fail-fast is enabled
+            if fail_fast:
+                console.print()
+                console.print("[yellow]⚠ Stopping tests due to --fail-fast[/yellow]")
+                break
+
         console.print()
 
+    # Update offering status based on test results (only if not using --test-file)
+    if not test_file and offering_test_results:
+        console.print("\n[cyan]Updating service offering status...[/cyan]")
+        for _offering_dir, test_stats in offering_test_results.items():
+            listing_file = test_stats["listing_file"]
+            passed = test_stats["passed"]
+            failed = test_stats["failed"]
+
+            # If any test failed, set to deprecated
+            if failed > 0:
+                update_offering_override_status(listing_file, UpstreamStatusEnum.deprecated)
+            # If all tests passed, remove deprecated status
+            elif passed > 0 and failed == 0:
+                update_offering_override_status(listing_file, None)
+
     # Print summary table
     console.print("\n" + "=" * 70)
     console.print("[bold]Test Results Summary:[/bold]\n")
@@ -806,13 +931,21 @@ def run(
     table.add_column("Exit Code", style="white")
 
     total_tests = len(results)
-    passed = sum(1 for r in results if r["result"]["success"])
-    failed = total_tests - passed
+    skipped = sum(1 for r in results if r["result"].get("skipped", False))
+    passed = sum(1 for r in results if r["result"]["success"] and not r["result"].get("skipped", False))
+    failed = total_tests - passed - skipped
 
     for test in results:
-        status = "[green]✓ Pass[/green]" if test["result"]["success"] else "[red]✗ Fail[/red]"
+        result = test["result"]
+        if result.get("skipped", False):
+            status = "[yellow]⊘ Skipped[/yellow]"
+        elif result["success"]:
+            status = "[green]✓ Pass[/green]"
+        else:
+            status = "[red]✗ Fail[/red]"
+
         # Use 'is not None' to properly handle exit_code of 0 (success)
-        exit_code = str(test["result"]["exit_code"]) if test["result"]["exit_code"] is not None else "N/A"
+        exit_code = str(result["exit_code"]) if result["exit_code"] is not None else "N/A"
 
         table.add_row(
             test["service_name"],
@@ -824,6 +957,8 @@ def run(
 
     console.print(table)
     console.print(f"\n[green]✓ Passed: {passed}/{total_tests}[/green]")
+    if skipped > 0:
+        console.print(f"[yellow]⊘ Skipped: {skipped}/{total_tests}[/yellow]")
     console.print(f"[red]✗ Failed: {failed}/{total_tests}[/red]")
 
     if failed > 0:
